@@ -8,6 +8,7 @@ from dovado_rtl.src_parsing import SourceParser
 from dovado_rtl.vivado_interaction import get_parts
 from dovado_rtl.antlr.hdl_representation import PortDirectionEnum
 from dovado_rtl.simple_types import Metric
+from movado import Movado
 
 
 def validate_power_of_2(value: List[str], ctx: typer.Context):
@@ -113,7 +114,10 @@ def validate_nearest_distance(value: int) -> int:
 
 
 def validate_estimator(value: str) -> str:
-    raise Exception("Validate estimator to be implemented")
+    movado = Movado()
+    if value in movado.get_models():
+        return value
+    raise typer.BadParameter("Invalid estimation model " + value + " available models are: " + str(movado.get_models()))
 
 
 def validate_board(value: str) -> str:
