@@ -8,6 +8,7 @@ class Configuration:
         # This switch controls if at each estimate call
         # also vivado is called in order to record approximation accuracy
         # against the real value
+        "SAMPLE_RECORD_CSV": "sample_record.csv",
         "ESTIMATION_TESTING": True,
         "EST_TEST_CSV": "estimation_accuracy.csv",
         # Dovado Working Dir
@@ -69,7 +70,7 @@ class Configuration:
     }
 
     def __init__(self):
-        config_path = Path("config.yaml")
+        config_path = Path("dovado.yaml")
         self.config: Dict[str, Union[str, int]] = yaml.safe_load(
             config_path.open()
         ) if config_path.is_file() else self.__config_dict
